==> func_adl_servicex_xaodr22-2.1.1.22.2.107b2-py3-none-any.whl: func_adl_servicex_xaodr22/xAOD/l1toposimresults_v1.py <==
from __future__ import annotations
import ast
from typing import Tuple, TypeVar, Iterable
from func_adl import ObjectStream, func_adl_callback, func_adl_parameterized_call
from enum import Enum
import func_adl_servicex_xaodr22

_method_map = {
    'connectionId': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::L1TopoSimResults_v1',
        'method_name': 'connectionId',
        'return_type': 'unsigned int',
    },
    'topoWord': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::L1TopoSimResults_v1',
        'method_name': 'topoWord',
        'return_type': 'unsigned int',
    },
    'topoWordOverflow': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::L1TopoSimResults_v1',
        'method_name': 'topoWordOverflow',
        'return_type': 'unsigned int',
    },
    'bitWidth': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::L1TopoSimResults_v1',
        'method_name': 'bitWidth',
        'return_type': 'unsigned int',
    },
    'clock': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::L1TopoSimResults_v1',
        'method_name': 'clock',
        'return_type': 'unsigned int',
    },
    'index': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::L1TopoSimResults_v1',
        'method_name': 'index',
        'return_type': 'int',
    },
    'usingPrivateStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::L1TopoSimResults_v1',
        'method_name': 'usingPrivateStore',
        'return_type': 'bool',
    },
    'usingStandaloneStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::L1TopoSimResults_v1',
        'method_name': 'usingStandaloneStore',
        'return_type': 'bool',
    },
    'hasStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::L1TopoSimResults_v1',
        'method_name': 'hasStore',
        'return_type': 'bool',
    },
    'hasNonConstStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::L1TopoSimResults_v1',
        'method_name': 'hasNonConstStore',
        'return_type': 'bool',
    },
    'clearDecorations': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::L1TopoSimResults_v1',
        'method_name': 'clearDecorations',
        'return_type': 'bool',
    },
    'trackIndices': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::L1TopoSimResults_v1',
        'method_name': 'trackIndices',
        'return_type': 'bool',
    },
    'auxdataConst': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::L1TopoSimResults_v1',
        'method_name': 'auxdataConst',
        'return_type': 'U',
    },
    'isAvailable': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::L1TopoSimResults_v1',
        'method_name': 'isAvailable',
        'return_type': 'bool',
    },
}

_enum_map = {      
}

T = TypeVar('T')


def _add_method_metadata(s: ObjectStream[T], a: ast.Call) -> Tuple[ObjectStream[T], ast.Call]:
    '''Add metadata for a collection to the func_adl stream if we know about it
    '''
    assert isinstance(a.func, ast.Attribute)
    if a.func.attr in _method_map:
        s_update = s.MetaData(_method_map[a.func.attr])

        s_update = s_update.MetaData({
            'metadata_type': 'inject_code',
            'name': 'xAODTrigger/versions/L1TopoSimResults_v1.h',
            'body_includes': ["xAODTrigger/versions/L1TopoSimResults_v1.h"],
        })


        s_update = s_update.MetaData({
            'metadata_type': 'inject_code',
            'name': 'xAODTrigger',
            'link_libraries': ["xAODTrigger"],
        })

        for md in _enum_map.get(a.func.attr, []):
            s_update = s_update.MetaData(md)
        return s_update, a
    else:
        return s, a


@func_adl_callback(_add_method_metadata)
class L1TopoSimResults_v1:
    "A class"


    def connectionId(self) -> int:
        "A method"
        ...

    def topoWord(self) -> int:
        "A method"
        ...

    def topoWordOverflow(self) -> int:
        "A method"
        ...

    def bitWidth(self) -> int:
        "A method"
        ...

    def clock(self) -> int:
        "A method"
        ...

    def index(self) -> int:
        "A method"
        ...

    def usingPrivateStore(self) -> bool:
        "A method"
        ...

    def usingStandaloneStore(self) -> bool:
        "A method"
        ...

    def hasStore(self) -> bool:
        "A method"
        ...

    def hasNonConstStore(self) -> bool:
        "A method"
        ...

    def clearDecorations(self) -> bool:
        "A method"
        ...

    def trackIndices(self) -> bool:
        "A method"
        ...

    @func_adl_parameterized_call(lambda s, a, param_1: func_adl_servicex_xaodr22.type_support.cpp_generic_1arg_callback('auxdataConst', s, a, param_1))
    @property
    def auxdataConst(self) -> func_adl_servicex_xaodr22.type_support.index_type_forwarder[func_adl_servicex_xaodr22.str.str]:
        "A method"
        ...

    @func_adl_parameterized_call(lambda s, a, param_1: func_adl_servicex_xaodr22.type_support.cpp_generic_1arg_callback('isAvailable', s, a, param_1))
    @property
    def isAvailable(self) -> func_adl_servicex_xaodr22.type_support.index_type_forwarder[func_adl_servicex_xaodr22.str.str]:
        "A method"
        ...

==> func_adl_servicex_xaodr22-2.2.0.22.2.113-py3-none-any.whl: func_adl_servicex_xaodr22/xAOD/l1toposimresults_v1.py <==
from __future__ import annotations
import ast
from typing import Tuple, TypeVar, Iterable
from func_adl import ObjectStream, func_adl_callback, func_adl_parameterized_call
from enum import Enum
import func_adl_servicex_xaodr22

_method_map = {
    'connectionId': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::L1TopoSimResults_v1',
        'method_name': 'connectionId',
        'return_type': 'unsigned int',
    },
    'topoWord': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::L1TopoSimResults_v1',
        'method_name': 'topoWord',
        'return_type': 'unsigned int',
    },
    'topoWord64': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::L1TopoSimResults_v1',
        'method_name': 'topoWord64',
        'return_type': 'uint64_t',
    },
    'topoWordOverflow': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::L1TopoSimResults_v1',
        'method_name': 'topoWordOverflow',
        'return_type': 'unsigned int',
    },
    'topoWord64Overflow': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::L1TopoSimResults_v1',
        'method_name': 'topoWord64Overflow',
        'return_type': 'uint64_t',
    },
    'bitWidth': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::L1TopoSimResults_v1',
        'method_name': 'bitWidth',
        'return_type': 'unsigned int',
    },
    'clock': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::L1TopoSimResults_v1',
        'method_name': 'clock',
        'return_type': 'unsigned int',
    },
    'index': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::L1TopoSimResults_v1',
        'method_name': 'index',
        'return_type': 'unsigned int',
    },
    'usingPrivateStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::L1TopoSimResults_v1',
        'method_name': 'usingPrivateStore',
        'return_type': 'bool',
    },
    'usingStandaloneStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::L1TopoSimResults_v1',
        'method_name': 'usingStandaloneStore',
        'return_type': 'bool',
    },
    'hasStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::L1TopoSimResults_v1',
        'method_name': 'hasStore',
        'return_type': 'bool',
    },
    'hasNonConstStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::L1TopoSimResults_v1',
        'method_name': 'hasNonConstStore',
        'return_type': 'bool',
    },
    'clearDecorations': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::L1TopoSimResults_v1',
        'method_name': 'clearDecorations',
        'return_type': 'bool',
    },
    'trackIndices': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::L1TopoSimResults_v1',
        'method_name': 'trackIndices',
        'return_type': 'bool',
    },
    'auxdataConst': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::L1TopoSimResults_v1',
        'method_name': 'auxdataConst',
        'return_type': 'U',
    },
    'isAvailable': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::L1TopoSimResults_v1',
        'method_name': 'isAvailable',
        'return_type': 'bool',
    },
}

_enum_map = {      
}

T = TypeVar('T')


def _add_method_metadata(s: ObjectStream[T], a: ast.Call) -> Tuple[ObjectStream[T], ast.Call]:
    '''Add metadata for a collection to the func_adl stream if we know about it
    '''
    assert isinstance(a.func, ast.Attribute)
    if a.func.attr in _method_map:
        s_update = s.MetaData(_method_map[a.func.attr])

        s_update = s_update.MetaData({
            'metadata_type': 'inject_code',
            'name': 'xAODTrigger/versions/L1TopoSimResults_v1.h',
            'body_includes': ["xAODTrigger/versions/L1TopoSimResults_v1.h"],
        })


        s_update = s_update.MetaData({
            'metadata_type': 'inject_code',
            'name': 'xAODTrigger',
            'link_libraries': ["xAODTrigger"],
        })

        for md in _enum_map.get(a.func.attr, []):
            s_update = s_update.MetaData(md)
        return s_update, a
    else:
        return s, a


@func_adl_callback(_add_method_metadata)
class L1TopoSimResults_v1:
    "A class"


    def connectionId(self) -> int:
        "A method"
        ...

    def topoWord(self) -> int:
        "A method"
        ...

    def topoWord64(self) -> int:
        "A method"
        ...

    def topoWordOverflow(self) -> int:
        "A method"
        ...

    def topoWord64Overflow(self) -> int:
        "A method"
        ...

    def bitWidth(self) -> int:
        "A method"
        ...

    def clock(self) -> int:
        "A method"
        ...

    def index(self) -> int:
        "A method"
        ...

    def usingPrivateStore(self) -> bool:
        "A method"
        ...

    def usingStandaloneStore(self) -> bool:
        "A method"
        ...

    def hasStore(self) -> bool:
        "A method"
        ...

    def hasNonConstStore(self) -> bool:
        "A method"
        ...

    def clearDecorations(self) -> bool:
        "A method"
        ...

    def trackIndices(self) -> bool:
        "A method"
        ...

    @func_adl_parameterized_call(lambda s, a, param_1: func_adl_servicex_xaodr22.type_support.cpp_generic_1arg_callback('auxdataConst', s, a, param_1))
    @property
    def auxdataConst(self) -> func_adl_servicex_xaodr22.type_support.index_type_forwarder[func_adl_servicex_xaodr22.str.str]:
        "A method"
        ...

    @func_adl_parameterized_call(lambda s, a, param_1: func_adl_servicex_xaodr22.type_support.cpp_generic_1arg_callback('isAvailable', s, a, param_1))
    @property
    def isAvailable(self) -> func_adl_servicex_xaodr22.type_support.index_type_forwarder[func_adl_servicex_xaodr22.str.str]:
        "A method"
        ...
